slackerade
==========

Masquerade yourself as fictitious user on slack

Usage
-----

::

    ./slackerade.py https://hooks.slack.com/services/CHANNEL/URL/HASH
    USERNAME MSG EMOJI_NAME

Example
-------

``./slackerade.py https://hooks.slack.com/services/<censured> "The Joker"  "That's the joke" ":thats_the_joke:"``

gives :

.. figure:: https://github.com/Kraymer/public/raw/master/slackerade/slackerade_demo.png
   :alt:
